/*
 * Copyright 2002-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.context.access;

import org.junit.Test;

import static org.junit.Assert.*;

import org.springframework.beans.factory.access.BeanFactoryLocator;

/**
 * @author Colin Sampaleanu
 */
public class DefaultLocatorFactoryTests {

	/*
	 * Class to test for BeanFactoryLocator getInstance()
	 */
	@Test
	public void getInstance() {
		BeanFactoryLocator bf = DefaultLocatorFactory.getInstance();
		BeanFactoryLocator bf2 = DefaultLocatorFactory.getInstance();
		assertTrue(bf.equals(bf2));
	}

	/*
	 * Class to test for BeanFactoryLocator getInstance(String)
	 */
	@Test
	public void getInstanceString() {
		BeanFactoryLocator bf = DefaultLocatorFactory.getInstance("my-bean-refs.xml");
		BeanFactoryLocator bf2 = DefaultLocatorFactory.getInstance("my-bean-refs.xml");
		assertTrue(bf.equals(bf2));
	}
}
